<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>À propos de Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Cette application est sous licence Apache version 2.0.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>et contributeurs :</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Site internet : %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Éditeur de mode de l&apos;appareil</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Canaux disponibles</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Canaux du mode</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="123"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Extension de fichier inconnue : %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Fixture loading failed</source>
        <translation>Échec du chargement de l&apos;appareil</translation>
    </message>
    <message>
        <location filename="app.cpp" line="148"/>
        <source>Unable to load fixture definition: </source>
        <translation>Impossible de charger la définition de l&apos;appareil : </translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="app.cpp" line="243"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="249"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>&amp;Save</source>
        <translation>Enregistrer (&amp;S)</translation>
    </message>
    <message>
        <location filename="app.cpp" line="255"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>Save &amp;As...</source>
        <translation>Enregistrer sous... (&amp;A)</translation>
    </message>
    <message>
        <location filename="app.cpp" line="261"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="app.cpp" line="267"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>Index</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="app.cpp" line="274"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="app.cpp" line="279"/>
        <source>About Fixture Definition Editor...</source>
        <translation>À propos de Fixture Definition Editor...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="284"/>
        <source>About Qt...</source>
        <translation>À propos de Qt...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="311"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="app.cpp" line="321"/>
        <source>&amp;Help</source>
        <translation>Aide (&amp;H)</translation>
    </message>
    <message>
        <location filename="app.cpp" line="359"/>
        <source>Open a fixture definition</source>
        <translation>Ouvrir la définition d&apos;un appareil</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Assistant de fonctionnalités</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Valeurs</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Début</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>La valeur DMX de départ</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Plage</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Le nombre de valeurs par fonctionnalité</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Quantité</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Le nombre de fonctionnalités à générer</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>La base commune du nom pour toutes les fonctionnalités (utilisez &apos;#&apos; pour générer un nombre incrémental).</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Fonctionnalité #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>La liste des fonctionnalités qui vont être générées selon les paramètres fournis</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="105"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Explorateur de documents</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="127"/>
        <source>Backward</source>
        <translation>Avant</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Forward</source>
        <translation>Arrière</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Index</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>Close this window</source>
        <translation>Fermer cette fenêtre</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Éditeur de canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Chevauchement de fonctionnalités détecté. Veuillez y remedier.&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation>Valeur par défaut</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation>Pré-réglage</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Le nom du canal en cours d&apos;édition</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation>Rôle</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation>Couleur 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation>Couleur 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation>Valeur 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation>Valeur 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>Le groupe auquel ce canal appartient</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Grossier (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fin (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Fonctionnalités</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Valeur minimum</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Valeur maximum</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Supprimer la fonctionnalité sélectionnée</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Assistant de fonctionnalité</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Éditeur de canal : </translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Chevauchement de valeurs</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Ouvrir un fichier de gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Images de gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation>Ressources manquantes</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation>Des gobos manquent:

</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Certaines fonctionnalités n&apos;ont pas pu être générées à cause d&apos;un chevauchement de valeurs.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Éditeur de tête</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Éditeur de mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Nom du mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="78"/>
        <source>Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="83"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="91"/>
        <source>Add channel(s) to this mode</source>
        <translation>Ajouter un ou plusieurs canaux à ce mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="111"/>
        <source>Remove the selected channel</source>
        <translation>Supprimer le canal sélectionné</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="131"/>
        <source>Raise the selected channel</source>
        <translation>Monter le canal sélectionné</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="151"/>
        <source>Lower the selected channel</source>
        <translation>Descendre le canal sélectionné</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="185"/>
        <source>Heads</source>
        <translation>Têtes</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="198"/>
        <source>Head</source>
        <translation>Tête</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Compose a new head</source>
        <translation>Définir une nouvelle tête</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="226"/>
        <source>Remove the selected head</source>
        <translation>Supprimer la tête sélectionnée</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="246"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Éditer les canaux qui appartiennent à la tête sélectionnée</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="266"/>
        <source>Raise the selected head</source>
        <translation>Monter la tête sélectionnée</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="286"/>
        <source>Lower the selected head</source>
        <translation>Descendre la tête sélectionnée</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="320"/>
        <source>Physical</source>
        <translation>Données physiques</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="330"/>
        <source>Use global settings</source>
        <translation>Utiliser les paramètres globaux</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="340"/>
        <source>Override global settings</source>
        <translation>Ne pas utiliser les paramètres globaux</translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Lampe</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumens</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Température de couleur (en K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Poids</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>&#xa0;kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Plage</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation> mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Profondeur</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation>Tête(s)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lentille</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Angle min</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Angle max</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Pan max (en °)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Tilt max (en °)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation>Disposition
(Colonnes × Lignes)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Électrique</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Consommation</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation> W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>Connecteur DMX</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Copier les données physiques dans le presse-papier</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Coller les données physiques depuis le presse-papier</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Appareil</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Fabricant</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>Le nom du fabricant de l&apos;appareil (ex : Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>Le nom du modèle de l&apos;appareil (ex : MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>Le type de l&apos;appareil</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="226"/>
        <source>LED Bar (Beams)</source>
        <translation type="unfinished">Barre LED (Beams)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="235"/>
        <source>LED Bar (Pixels)</source>
        <translation>Barre LED (Pixels)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Le nom de l&apos;auteur de ce fichier de définition</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Ajouter un canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Supprimer le canal sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Éditer le canal sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Copier le canal dans le presse-papier</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Coller le canal depuis le presse-papier vers cet appareil</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Déplier/Replier tous les canaux</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Têtes</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Ajouter un mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Supprimer le mode sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Éditer le mode sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Dupliquer le mode sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Déplier/Replier tous les modes</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation>Dans le mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation>Ajouter un nouvel alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation>avec</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation>remplace</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation>Canal d&apos;origine</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation>Canal modifié</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation>Supprimer l&apos;alias sélectionné</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation>Données physiques</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Voulez vous enregistrer les modifications de l&apos;appareil
&quot;%1&quot;
avant de quitter&#xa0;?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Information importante manquante</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Nom du fabricant manquant.
Impossible d&apos;enregistrer l&apos;appareil.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Nom du modèle manquant.
Impossible d&apos;enregistrer l&apos;appareil.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Erreur lors de l&apos;enregistrement</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Impossible d&apos;enregistrer la définition de l&apos;appareil :
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Enregistrer la définition de l&apos;appareil</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Nouvel appareil</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="534"/>
        <source>Channel already exists</source>
        <translation>Canal existant</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="535"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Un canal avec le nom &quot;%1&quot; existe déjà
!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="541"/>
        <source>Channel has no name</source>
        <translation>Nom du canal manquant</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="542"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Veuillez donner un nom au canal
!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Êtes-vous sûr(e) de vouloir supprimer le canal &quot;%1&quot;&#xa0;?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="813"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Êtes-vous sûr(e) de vouloir supprimer le mode &quot;%1&quot;&#xa0;?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="654"/>
        <location filename="fixtureeditor.cpp" line="689"/>
        <location filename="fixtureeditor.cpp" line="914"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="655"/>
        <location filename="fixtureeditor.cpp" line="691"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="656"/>
        <location filename="fixtureeditor.cpp" line="693"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="657"/>
        <location filename="fixtureeditor.cpp" line="695"/>
        <location filename="fixtureeditor.cpp" line="920"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="766"/>
        <location filename="fixtureeditor.cpp" line="775"/>
        <source>Unable to add mode</source>
        <translation>Impossible d&apos;ajouter un mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="767"/>
        <source>Another mode by that name already exists</source>
        <translation>Un mode portant ce nom existe déjà</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="776"/>
        <source>You must give a name to the mode</source>
        <translation>Veuillez donner un nom au mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="812"/>
        <source>Remove Mode</source>
        <translation>Suppression du mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="860"/>
        <source>Rename new mode</source>
        <translation>Nommage du nouveau mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="861"/>
        <source>Give a unique name for the mode</source>
        <translation>Donnez un nom unique au nouveau mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="863"/>
        <source>Copy of %1</source>
        <translation>Copie de %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="873"/>
        <source>Invalid name</source>
        <translation>Nom invalide</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Another mode by that name already exists.</source>
        <translation>Un mode portant ce nom existe déjà.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="917"/>
        <source>Clone</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="925"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
</context>
</TS>
